@@ -273,10 +273,10 @@ class deepmdInputGenerator():
             print('everything is fine, generating the input json file now') 
         
         tmp_dict = {
-            'model': model,
-            'learning_rate': learning_rate,
-            'loss': loss,
-            'training': training
+            'model': self.model,
+            'learning_rate': self.learning_rate,
+            'loss': self.loss,
+            'training': self.training
         }
         f = open(filename,'w+')
         json.dump(tmp_dict, f)
